@@ -26,7 +26,7 @@ class CollectionCloner:
         self.des_db_name = self.config.get('des_db_name', '')
         self.user = self.config.get('user', '')
         self.password = self.config.get('password', '')
-        self.des_col_name = self.config.get('des_col', '')
+        self.des_col_name = self.config.get('des_col_name', '')
         self.des_ip = self.config.get('des_ip', '')
         
         if self.mode == 'll':
